﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Windows;
using System.Windows.Controls;

namespace ThinkGeo.MapSuite.VehicleTracking
{
    /// <summary>
    /// Interaction logic for OverlaySwitcher.xaml
    /// </summary>
    public partial class OverlaySwitcher
    {
        public static readonly DependencyProperty OverlayNamesProperty = DependencyProperty.Register("OverlayNames", typeof(IEnumerable<string>), typeof(OverlaySwitcher), new PropertyMetadata(new Collection<string>()));
        public static readonly DependencyProperty DefaultOverlayNameProperty = DependencyProperty.Register("DefaultOverlayName", typeof(string), typeof(OverlaySwitcher), new PropertyMetadata(""));

        public event EventHandler<OverlayChangedOverlaySwitcherEventArgs> OverlayChanged;

        private string checkedOverlayName;

        public OverlaySwitcher()
        {
            InitializeComponent();
        }

        public string DefaultOverlayName
        {
            get { return (string)GetValue(DefaultOverlayNameProperty); }
            set { SetValue(DefaultOverlayNameProperty, value); }
        }

        public IEnumerable<string> OverlayNames
        {
            get { return (IEnumerable<string>)GetValue(OverlayNamesProperty); }
            set { SetValue(OverlayNamesProperty, value); }
        }

        public string CollapseImageUri { get; set; }

        public string ExpandImageUri { get; set; }

        public void BindingOverlayNames(string overlayName)
        {
            Dictionary<string, bool> overlays = new Dictionary<string, bool>();
            foreach (string name in OverlayNames)
            {
                overlays[name] = name.Equals(overlayName);
            }
            itemsControl.ItemsSource = overlays;
            checkedOverlayName = overlayName;
        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            if (string.IsNullOrEmpty(DefaultOverlayName)) DefaultOverlayName = OverlayNames.FirstOrDefault();
            BindingOverlayNames(DefaultOverlayName);
            checkedOverlayName = DefaultOverlayName;

            collapseExpandButton.Content = new Uri(ExpandImageUri, UriKind.RelativeOrAbsolute);
        }

        protected virtual void OnOverlayChanged(OverlayChangedOverlaySwitcherEventArgs e)
        {
            EventHandler<OverlayChangedOverlaySwitcherEventArgs> handler = OverlayChanged;
            if (handler != null)
            {
                handler(this, e);
            }
        }

        private void OverlayChecked(object sender, RoutedEventArgs e)
        {
            RadioButton radioButton = (RadioButton)sender;
            if (radioButton != null && radioButton.Content != null)
            {
                string overlayName = radioButton.Content.ToString();
                OverlayChangedOverlaySwitcherEventArgs overlaySwitchedEventArgs = new OverlayChangedOverlaySwitcherEventArgs(checkedOverlayName, overlayName);
                OnOverlayChanged(overlaySwitchedEventArgs);
                BindingOverlayNames(overlayName);
            }
        }

        private void CollaspeExpandOverlaySwitcherClick(object sender, RoutedEventArgs e)
        {
            if (borderPanel.Visibility == Visibility.Visible)
            {
                borderPanel.Visibility = Visibility.Collapsed;
                ((Button)sender).Content = new Uri(CollapseImageUri, UriKind.RelativeOrAbsolute);
            }
            else
            {
                borderPanel.Visibility = Visibility.Visible;
                ((Button)sender).Content = new Uri(ExpandImageUri, UriKind.RelativeOrAbsolute);
            }
        }
    }
}
